@@ -21,6 +21,11 @@ describe 'oslo::cache' do
         is_expected.to contain_keystone_config('cache/memcache_pool_maxsize').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('cache/memcache_pool_unused_timeout').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('cache/memcache_pool_connection_get_timeout').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_keystone_config('cache/tls_enabled').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_keystone_config('cache/tls_cafile').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_keystone_config('cache/tls_certfile').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_keystone_config('cache/tls_keyfile').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_keystone_config('cache/tls_allowed_ciphers').with_value('<SERVICE DEFAULT>')
       end
     end
 
@@ -40,6 +45,11 @@ describe 'oslo::cache' do
           :memcache_pool_maxsize                => '10',
           :memcache_pool_unused_timeout         => '60',
           :memcache_pool_connection_get_timeout => '10',
+          :tls_enabled                          => false,
+          :tls_cafile                           => nil,
+          :tls_certfile                         => nil,
+          :tls_keyfile                          => nil,
+          :tls_allowed_ciphers                  => nil,
         }
       end
 
@@ -57,6 +67,11 @@ describe 'oslo::cache' do
         is_expected.to contain_keystone_config('cache/memcache_pool_maxsize').with_value('10')
         is_expected.to contain_keystone_config('cache/memcache_pool_unused_timeout').with_value('60')
         is_expected.to contain_keystone_config('cache/memcache_pool_connection_get_timeout').with_value('10')
+        is_expected.to contain_keystone_config('cache/tls_enabled').with_value('false')
+        is_expected.to contain_keystone_config('cache/tls_cafile').with_value('nil')
+        is_expected.to contain_keystone_config('cache/tls_certfile').with_value('nil')
+        is_expected.to contain_keystone_config('cache/tls_keyfile').with_value('nil')
+        is_expected.to contain_keystone_config('cache/tls_allowed_ciphers').with_value('nil')
       end
     end
 
@@ -70,12 +85,28 @@ describe 'oslo::cache' do
       it 'configures cache backend' do
         is_expected.to contain_keystone_config('cache/backend').with_value('dogpile.cache.pylibmc')
         is_expected.to contain_package('python-pylibmc').with(
-          :ensure => 'present',
+          :ensure => 'installed',
           :name   => platform_params[:pylibmc_package_name],
           :tag    => 'openstack',
         )
       end
 
+      context 'with package_ensure set' do
+        before do
+          params.merge!({
+            :package_ensure => 'latest'
+          })
+        end
+
+        it 'ensures status of the package' do
+          is_expected.to contain_package('python-pylibmc').with(
+            :ensure => 'latest',
+            :name   => platform_params[:pylibmc_package_name],
+            :tag    => 'openstack',
+          )
+        end
+      end
+
       context 'with backend package management disabled' do
         before do
           params.merge!({
@@ -99,11 +130,28 @@ describe 'oslo::cache' do
       it 'configures cache backend' do
         is_expected.to contain_keystone_config('cache/backend').with_value('dogpile.cache.memcache')
         is_expected.to contain_package('python-memcache').with(
+          :ensure => 'installed',
           :name   => platform_params[:python_memcache_package_name],
           :tag    => ['openstack'],
         )
       end
 
+      context 'with package_ensure set' do
+        before do
+          params.merge!({
+            :package_ensure => 'latest'
+          })
+        end
+
+        it 'ensures status of the package' do
+          is_expected.to contain_package('python-memcache').with(
+            :ensure => 'latest',
+            :name   => platform_params[:python_memcache_package_name],
+            :tag    => ['openstack'],
+          )
+        end
+      end
+
       context 'with backend package management disabled' do
         before do
           params.merge!({
@@ -117,6 +165,51 @@ describe 'oslo::cache' do
       end
     end
 
+    context 'with etcd3gw backend' do
+      let :params do
+        {
+          :backend => 'oslo_cache.etcd3gw',
+        }
+      end
+
+      it 'configures cache backend' do
+        is_expected.to contain_keystone_config('cache/backend').with_value('oslo_cache.etcd3gw')
+        is_expected.to contain_package('python-etcd3gw').with(
+          :ensure => 'installed',
+          :name   => platform_params[:python_etcd3gw_package_name],
+          :tag    => ['openstack'],
+        )
+      end
+
+      context 'with package_ensure set' do
+        before do
+          params.merge!({
+            :package_ensure => 'latest'
+          })
+        end
+
+        it 'ensures status of the package' do
+          is_expected.to contain_package('python-etcd3gw').with(
+            :ensure => 'latest',
+            :name   => platform_params[:python_etcd3gw_package_name],
+            :tag    => 'openstack',
+          )
+        end
+      end
+
+      context 'with backend package management disabled' do
+        before do
+          params.merge!({
+            :manage_backend_package => false,
+          })
+        end
+
+        it 'does not install backend package' do
+          is_expected.not_to contain_package('python-etcd3gw')
+        end
+      end
+    end
+
     context 'with string in list parameters' do
       let :params do
         {
@@ -146,20 +239,12 @@ describe 'oslo::cache' do
         case facts[:osfamily]
         when 'Debian'
           { :pylibmc_package_name         => 'python3-pylibmc',
-            :python_memcache_package_name => 'python3-memcache' }
+            :python_memcache_package_name => 'python3-memcache',
+            :python_etcd3gw_package_name  => 'python3-etcd3gw' }
         when 'RedHat'
-          if facts[:operatingsystem] == 'Fedora'
-            { :pylibmc_package_name         => 'python3-pylibmc',
-              :python_memcache_package_name => 'python3-memcached' }
-          else
-            if facts[:operatingsystemmajrelease] > '7'
-              { :pylibmc_package_name         => 'python3-pylibmc',
-                :python_memcache_package_name => 'python3-memcached' }
-            else
-              { :pylibmc_package_name         => 'python-pylibmc',
-                :python_memcache_package_name => 'python-memcached' }
-            end
-          end
+          { :pylibmc_package_name         => 'python3-pylibmc',
+            :python_memcache_package_name => 'python3-memcached',
+            :python_etcd3gw_package_name  => 'python3-etcd3gw' }
         end
       end
 
